@@ -7,16 +7,15 @@ var group__rate__control =
     [ "av1_firstpass_info_push", "group__rate__control.html#ga05ee091c593e5672c6be2d0bdd89d1cb", null ],
     [ "av1_firstpass_info_peek", "group__rate__control.html#ga1930a02e62c42b75313b987806837c84", null ],
     [ "av1_firstpass_info_future_count", "group__rate__control.html#gadfe05128d22bba397120763fe132c867", null ],
-    [ "av1_firstpass_info_past_count", "group__rate__control.html#ga6ae4ccee614dac82eb20d16c30d6cbe9", null ],
     [ "av1_first_pass", "group__rate__control.html#ga2a0f590eb2dc358f9781654644a2519d", null ],
     [ "av1_gop_setup_structure", "group__rate__control.html#ga6853e4fcc63f2f54ae429e27286827ae", null ],
-    [ "av1_gop_bit_allocation", "group__rate__control.html#gac12d62af325ff26685a28bebb0137a65", null ],
     [ "av1_gop_check_forward_keyframe", "group__rate__control.html#gac1743a047b06169064f57c74288d7537", null ],
     [ "av1_gop_is_second_arf", "group__rate__control.html#ga50283a647b83308a9a7c02b74a980ac1", null ],
     [ "av1_get_second_pass_params", "group__rate__control.html#ga2c30e6d5b7f0c87a7aa61cabace6905c", null ],
     [ "av1_twopass_postencode_update", "group__rate__control.html#gae9eddc0e6469d28bd0429c03efe97544", null ],
     [ "get_twopass_worst_quality", "group__rate__control.html#gaf73c75a80818ad2b556f6d86a7e71c5f", null ],
     [ "calculate_total_gf_group_bits", "group__rate__control.html#gaa1b79c4de593c5ddccf4f0384d51e901", null ],
+    [ "av1_gop_bit_allocation", "group__rate__control.html#ga426b046f33877ffb22e3566c52e19f53", null ],
     [ "get_rate_correction_factor", "group__rate__control.html#ga2739ae83fcd1266a2b44aae1ee40e57f", null ],
     [ "set_rate_correction_factor", "group__rate__control.html#gae256aad9cb7fbcb22b6944d5b3053a1f", null ],
     [ "find_closest_qindex_by_rate", "group__rate__control.html#ga8cc1e01e3fb0a620ea3a7ab53d94eb6e", null ],
@@ -26,6 +25,7 @@ var group__rate__control =
     [ "rc_pick_q_and_bounds", "group__rate__control.html#ga788dbcf3c2f97056f0ca1fd644a4535f", null ],
     [ "av1_set_rtc_reference_structure_one_layer", "group__rate__control.html#gaf3b990f88a7036986750f9ae344129e9", null ],
     [ "rc_scene_detection_onepass_rt", "group__rate__control.html#ga279fa44cf40d3cced9cf06f9acbdfb4e", null ],
+    [ "rc_spatial_act_onepass_rt", "group__rate__control.html#gaa07fd8beaee23818bb11c95e80fcf457", null ],
     [ "set_gf_interval_update_onepass_rt", "group__rate__control.html#ga7778c29e995a78b2521fe4f0bab0c9c1", null ],
     [ "dynamic_resize_one_pass_cbr", "group__rate__control.html#ga4770b9bf9d2f350267d57a8dcc48d0a2", null ],
     [ "av1_rc_update_rate_correction_factors", "group__rate__control.html#ga23765f9ab795ae26c6949163ceb9a4e3", null ],
@@ -37,6 +37,7 @@ var group__rate__control =
     [ "av1_calc_iframe_target_size_one_pass_cbr", "group__rate__control.html#gab8e7c90f91decf78f31360e56b7f1be6", null ],
     [ "av1_get_one_pass_rt_params", "group__rate__control.html#ga5aa5d85250b9dd9951113b4c7053dd43", null ],
     [ "av1_encodedframe_overshoot_cbr", "group__rate__control.html#ga4d75c27a723a602ab5b4c497cea07993", null ],
+    [ "av1_postencode_drop_cbr", "group__rate__control.html#ga9012098755b41f37b57a3cbc81b94391", null ],
     [ "recode_loop_test", "group__rate__control.html#ga9c1efbd9f79914ed44ee7a6a795381d5", null ],
     [ "recode_loop_update_q", "group__rate__control.html#gacd9a4ebbc3f3c5203419152558dcb17a", null ],
     [ "get_layer_context", "group__rate__control.html#ga08d8e6c33750a282d5a9dc66252fda45", null ]
