@@ -185,14 +185,14 @@ var NAVTREEINDEX =
 "encoder_guide.html#architecture_enc_gf_length",
 "group__aom__encoder.html#ga5a44302260efb45ebf560f7fb0b4352b",
 "group__codec.html#gaf35aecefb8133a5474d0068119e6182c",
-"group__speed__features.html#ga95ee4b0969a41da950b5c23909d142c4",
-"structAV1__COMP.html#a61ca5f788df7db66a40f902f8929bf3f",
-"structCommonQuantParams.html#a184dcbe8f484a0d1d224f367224a5379",
-"structLV__MAP__COEFF__COST.html#ac13625e52afc8b9f56490d9b4e3763c8",
-"structResizeCfg.html#a648d5bb8effb5ece1b5e7abcd4f2a197",
-"structaom__codec__enc__cfg.html#a8f8851455e06db026022d4b01671b122",
-"structcfg__options.html#aab0e968a76c1dd31fbfdee7b099b7828"
+"group__src__frame__proc.html",
+"structAV1__COMP.html#a62a2e36e5f53412363680d402a958ece",
+"structCommonQuantParams.html#a2ad05f39cabcdd12d9bd34136788793a",
+"structLV__MAP__COEFF__COST.html#ad30ba41c53bce80c8f4c06a966a71204",
+"structResizeCfg.html#a88f92c8f849f948f7794ba230ed52a25",
+"structaom__codec__enc__cfg.html#a9217f81f33c62161df9d94e42f2b77c6",
+"structcfg__options.html#abf48d913552cb6b4f35ffdaf988c5dd8"
 ];
 
-var SYNCONMSG = 'click to disable panel synchronisation';
-var SYNCOFFMSG = 'click to enable panel synchronisation';
\ No newline at end of file
+var SYNCONMSG = 'click to disable panel synchronization';
+var SYNCOFFMSG = 'click to enable panel synchronization';
\ No newline at end of file
