@@ -1,5 +1,6 @@
 var NAVTREEINDEX1 =
 {
+"encoder_guide.html#architecture_enc_gf_length":[8,7,2],
 "encoder_guide.html#architecture_enc_gf_structure":[8,7,3],
 "encoder_guide.html#architecture_enc_inter_modes":[8,11],
 "encoder_guide.html#architecture_enc_intra_modes":[8,10],
@@ -248,6 +249,5 @@ var NAVTREEINDEX1 =
 "group__aom__encoder.html#ga4af3be5d269421964fc8b3e8681121dd":[12,1,0,0,64],
 "group__aom__encoder.html#ga4b28cbe3036a6f1c5753fa461facc192":[12,1,0,0,81],
 "group__aom__encoder.html#ga50c2560ca6670298cfc614ecae96a391":[12,1,0,0,32],
-"group__aom__encoder.html#ga58817629f5270c0db0851e354cd6e57c":[12,1,0,0,46],
-"group__aom__encoder.html#ga5a44302260efb45ebf560f7fb0b4352b":[12,1,0,0,22]
+"group__aom__encoder.html#ga58817629f5270c0db0851e354cd6e57c":[12,1,0,0,46]
 };
