@@ -1,19 +1,30 @@
 var NAVTREEINDEX3 =
 {
-"group__codec.html#ggaaae61e0f8663e6137f1e228757248e7ca413c6090fa855359106e32fbd2b5f668":[12,0,32,9],
-"group__codec.html#ggaaae61e0f8663e6137f1e228757248e7ca7cbf0a1ff28bf7c460f6d86d63b30842":[12,0,32,3],
-"group__codec.html#ggaaae61e0f8663e6137f1e228757248e7ca8b4b7f7b3ea2a3a0e07b82c9170775a2":[12,0,32,7],
-"group__codec.html#ggaaae61e0f8663e6137f1e228757248e7ca94436b9b9d07909fe2e85b39ef0b5615":[12,0,32,6],
-"group__codec.html#ggaaae61e0f8663e6137f1e228757248e7caa4328d9fc527a3fd3cf76eb54e3db1a2":[12,0,32,2],
-"group__codec.html#ggaaae61e0f8663e6137f1e228757248e7cac4a4eea6394661cef74abf674c12cfa8":[12,0,32,4],
-"group__codec.html#ggaaae61e0f8663e6137f1e228757248e7caf145dc2f86014a08ebad36ac2b140001":[12,0,32,0],
-"group__codec.html#ggac34a24f7c6c0fef7518aed0da4425f61a17127133dafcd42b1d792770981d67d0":[12,0,34,1],
-"group__codec.html#ggac34a24f7c6c0fef7518aed0da4425f61a5abd24080a18d4f7e33217d93a73e968":[12,0,34,0],
-"group__codec.html#ggac34a24f7c6c0fef7518aed0da4425f61aaabb4d9ad771b2fa177ff6fb5437b179":[12,0,34,2],
+"group__codec.html#gaf35aecefb8133a5474d0068119e6182c":[12,0,18],
+"group__codec.html#gaf452ede024bf9a378fa66443494070ba":[12,0,20],
+"group__codec.html#gaf4a58f123913a5eef0a3796f0619e5f3":[12,0,12],
+"group__codec.html#gaf776d31e60e32bee1cdbaf052a8ea12a":[12,0,28],
+"group__codec.html#gaf89686fae8fc9db433d6ee525ae93cda":[12,0,40],
+"group__codec.html#gafc4f21abef83316131df07742b919d91":[12,0,19],
+"group__codec.html#gga6ed0e98eba4651c1ad845e39498e4153a15836a87f9e9940885d5ef59a52bf728":[12,0,34,2],
+"group__codec.html#gga6ed0e98eba4651c1ad845e39498e4153a4c7f55539160206a3fbb2a6cfc9ef89c":[12,0,34,0],
+"group__codec.html#gga6ed0e98eba4651c1ad845e39498e4153a91734384f432233c3d681052122ab8e7":[12,0,34,1],
+"group__codec.html#ggaaae61e0f8663e6137f1e228757248e7ca0c6ff8587f8bcc0429aecfa9fe2762df":[12,0,33,8],
+"group__codec.html#ggaaae61e0f8663e6137f1e228757248e7ca20f818786bc939e6e58192f6a150d691":[12,0,33,1],
+"group__codec.html#ggaaae61e0f8663e6137f1e228757248e7ca38b6a9786805f6c215cff72985cc6fdb":[12,0,33,5],
+"group__codec.html#ggaaae61e0f8663e6137f1e228757248e7ca413c6090fa855359106e32fbd2b5f668":[12,0,33,9],
+"group__codec.html#ggaaae61e0f8663e6137f1e228757248e7ca7cbf0a1ff28bf7c460f6d86d63b30842":[12,0,33,3],
+"group__codec.html#ggaaae61e0f8663e6137f1e228757248e7ca8b4b7f7b3ea2a3a0e07b82c9170775a2":[12,0,33,7],
+"group__codec.html#ggaaae61e0f8663e6137f1e228757248e7ca94436b9b9d07909fe2e85b39ef0b5615":[12,0,33,6],
+"group__codec.html#ggaaae61e0f8663e6137f1e228757248e7caa4328d9fc527a3fd3cf76eb54e3db1a2":[12,0,33,2],
+"group__codec.html#ggaaae61e0f8663e6137f1e228757248e7cac4a4eea6394661cef74abf674c12cfa8":[12,0,33,4],
+"group__codec.html#ggaaae61e0f8663e6137f1e228757248e7caf145dc2f86014a08ebad36ac2b140001":[12,0,33,0],
+"group__codec.html#ggac34a24f7c6c0fef7518aed0da4425f61a17127133dafcd42b1d792770981d67d0":[12,0,35,1],
+"group__codec.html#ggac34a24f7c6c0fef7518aed0da4425f61a5abd24080a18d4f7e33217d93a73e968":[12,0,35,0],
+"group__codec.html#ggac34a24f7c6c0fef7518aed0da4425f61aaabb4d9ad771b2fa177ff6fb5437b179":[12,0,35,2],
 "group__codecs.html":[12,1],
 "group__coefficient__coding.html":[12,2,5],
 "group__coefficient__coding.html#ga0076c2c06ae74fd7b00193d4aa2f1d46":[12,2,5,4],
-"group__coefficient__coding.html#ga1618c5468421234169f9b285bc70a59c":[12,2,5,13],
 "group__coefficient__coding.html#ga1f9147fbeb6681f1f2ffd99806c93526":[12,2,5,0],
 "group__coefficient__coding.html#ga225614c4ff1863904ee8a80e0d971cc4":[12,2,5,12],
 "group__coefficient__coding.html#ga24b28c5ec4bc705cc58a7655c8218e4d":[12,2,5,3],
@@ -103,24 +114,23 @@ var NAVTREEINDEX3 =
 "group__encoder__algo.html":[12,2],
 "group__gf__group__algo.html":[12,2,0,6],
 "group__gf__group__algo.html#ga294931863e7bb9104cdab552e06dbbd9":[12,2,0,6,0],
-"group__gf__group__algo.html#ga4cb741db8437bc066db6bf8eeb8f7128":[12,2,0,6,3],
-"group__gf__group__algo.html#ga67628538a2f36718ec7c924ce5328de2":[12,2,0,6,4],
+"group__gf__group__algo.html#ga67628538a2f36718ec7c924ce5328de2":[12,2,0,6,3],
 "group__gf__group__algo.html#ga89a0a5ad12dd9a8d35030ab51d5c4fe5":[12,2,0,6,1],
-"group__gf__group__algo.html#ga9aa97f1bc97fd44160e858d375c0c20f":[12,2,0,6,5],
+"group__gf__group__algo.html#ga9aa97f1bc97fd44160e858d375c0c20f":[12,2,0,6,4],
 "group__gf__group__algo.html#ga9b50f914d4997b65c3945a185393fe82":[12,2,0,6,2],
 "group__high__level__algo.html":[12,2,0],
-"group__high__level__algo.html#ga0d530935e53f27ab76f0dada5a8b94b6":[12,2,0,16],
 "group__high__level__algo.html#ga0f59145ac0765033ee267ba203baed23":[12,2,0,12],
-"group__high__level__algo.html#ga29eed659e71f7b8e1aef31d8cb4bb9ea":[12,2,0,7],
 "group__high__level__algo.html#ga4017ec9e9cfd7bd461775266c80ff46d":[12,2,0,18],
-"group__high__level__algo.html#ga681c10fbb05a4c91b4536107f3342c37":[12,2,0,17],
-"group__high__level__algo.html#ga6b56870ab498cf798e1e16c38b4c197c":[12,2,0,8],
+"group__high__level__algo.html#ga4a16556b66539d8aaac1cfb7c2e0ade7":[12,2,0,19],
+"group__high__level__algo.html#ga60a25ca37c27c82780bfb6e7e14ace9a":[12,2,0,8],
+"group__high__level__algo.html#ga7064d408b405d4cc0e85911c83a70d15":[12,2,0,17],
+"group__high__level__algo.html#ga741413aedeba6ee96acf6f733fdda36e":[12,2,0,7],
+"group__high__level__algo.html#ga798b1342ed714595819294c74df375f2":[12,2,0,14],
+"group__high__level__algo.html#ga7a6d2a81ccf6a6f0e91d935f3dbfd2bd":[12,2,0,15],
 "group__high__level__algo.html#ga7c707e2dc0a45e03ee9cd81f97552a0b":[12,2,0,9],
 "group__high__level__algo.html#ga87fccf520455ff9a41aa381b40b8862c":[12,2,0,13],
 "group__high__level__algo.html#ga9f2d93e66cde2eccb5f4dcd5d08c6d6a":[12,2,0,10],
-"group__high__level__algo.html#gac237dcb6e36d4dbff616e618ab4985a6":[12,2,0,14],
-"group__high__level__algo.html#gad4f93a0174051f16f9010f332f6c9bc7":[12,2,0,19],
-"group__high__level__algo.html#gaec07a41d07f7cd08a258531cd8935c68":[12,2,0,15],
+"group__high__level__algo.html#gab26a44ff31f4575a3577f043f5d63711":[12,2,0,16],
 "group__high__level__algo.html#gafca3ffd2882283c32dbb6f958a7c6e04":[12,2,0,11],
 "group__in__loop__cdef.html":[12,2,7],
 "group__in__loop__cdef.html#ga11bf0a29a7e25b59e680c6b44439af5f":[12,2,7,1],
@@ -168,15 +178,15 @@ var NAVTREEINDEX3 =
 "group__nonrd__mode__search.html#gafa44920244086ceee2883b80341c61d8":[12,2,12,0],
 "group__palette__mode__search.html":[12,2,2,0],
 "group__palette__mode__search.html#ga147640a97b720f170176589f40052988":[12,2,2,0,9],
-"group__palette__mode__search.html#ga2cb9b1049cdc0060881083633ccee68f":[12,2,2,0,5],
-"group__palette__mode__search.html#ga3ef821348e6d88fc171a8af5d070a5ca":[12,2,2,0,3],
-"group__palette__mode__search.html#ga80f626349d4e58b164c7a57fefbcd83a":[12,2,2,0,8],
-"group__palette__mode__search.html#gaa6a39d9de82e0e5cd963473067334e17":[12,2,2,0,4],
+"group__palette__mode__search.html#ga2cb9b1049cdc0060881083633ccee68f":[12,2,2,0,4],
+"group__palette__mode__search.html#ga3ef821348e6d88fc171a8af5d070a5ca":[12,2,2,0,2],
+"group__palette__mode__search.html#ga80f626349d4e58b164c7a57fefbcd83a":[12,2,2,0,7],
+"group__palette__mode__search.html#gaa6a39d9de82e0e5cd963473067334e17":[12,2,2,0,3],
 "group__palette__mode__search.html#gab303c97534cd091ada24b034289a21a4":[12,2,2,0,1],
 "group__palette__mode__search.html#gab8813de381028651eb53216b019430b9":[12,2,2,0,0],
-"group__palette__mode__search.html#gab9bf846634be27493a882c390fd7bc55":[12,2,2,0,6],
-"group__palette__mode__search.html#gaf6eaf3e49c594d167c458e7cced8bd50":[12,2,2,0,2],
-"group__palette__mode__search.html#gafab99f1ec2dfb2267b7396f474ecfaf0":[12,2,2,0,7],
+"group__palette__mode__search.html#gab9bf846634be27493a882c390fd7bc55":[12,2,2,0,5],
+"group__palette__mode__search.html#gacfb197722cfb1802e62f7fc6b66da8c8":[12,2,2,0,8],
+"group__palette__mode__search.html#gafab99f1ec2dfb2267b7396f474ecfaf0":[12,2,2,0,6],
 "group__partition__search.html":[12,2,1],
 "group__partition__search.html#ga0664c147707f2d528d53cc09a7f41e20":[12,2,1,9],
 "group__partition__search.html#ga0d32a492481d81049254d362c3046d41":[12,2,1,5],
@@ -196,58 +206,48 @@ var NAVTREEINDEX3 =
 "group__partition__search.html#gae25f4a644301f19a32106425997965c6":[12,2,1,3],
 "group__rate__control.html":[12,2,0,2],
 "group__rate__control.html#ga05ee091c593e5672c6be2d0bdd89d1cb":[12,2,0,2,4],
-"group__rate__control.html#ga08d8e6c33750a282d5a9dc66252fda45":[12,2,0,2,39],
+"group__rate__control.html#ga08d8e6c33750a282d5a9dc66252fda45":[12,2,0,2,40],
 "group__rate__control.html#ga174d96c77a72a090d5e218346a91d4c2":[12,2,0,2,31],
 "group__rate__control.html#ga1930a02e62c42b75313b987806837c84":[12,2,0,2,5],
 "group__rate__control.html#ga1f1b566e7234deb8018a0bd3dc3822d7":[12,2,0,2,1],
 "group__rate__control.html#ga23765f9ab795ae26c6949163ceb9a4e3":[12,2,0,2,28],
-"group__rate__control.html#ga2739ae83fcd1266a2b44aae1ee40e57f":[12,2,0,2,17],
-"group__rate__control.html#ga279fa44cf40d3cced9cf06f9acbdfb4e":[12,2,0,2,25],
-"group__rate__control.html#ga2a0f590eb2dc358f9781654644a2519d":[12,2,0,2,8],
-"group__rate__control.html#ga2c30e6d5b7f0c87a7aa61cabace6905c":[12,2,0,2,13],
+"group__rate__control.html#ga2739ae83fcd1266a2b44aae1ee40e57f":[12,2,0,2,16],
+"group__rate__control.html#ga279fa44cf40d3cced9cf06f9acbdfb4e":[12,2,0,2,24],
+"group__rate__control.html#ga2a0f590eb2dc358f9781654644a2519d":[12,2,0,2,7],
+"group__rate__control.html#ga2c30e6d5b7f0c87a7aa61cabace6905c":[12,2,0,2,11],
+"group__rate__control.html#ga426b046f33877ffb22e3566c52e19f53":[12,2,0,2,15],
 "group__rate__control.html#ga45ce59a77756df79d6fdbdae82158a41":[12,2,0,2,2],
 "group__rate__control.html#ga4770b9bf9d2f350267d57a8dcc48d0a2":[12,2,0,2,27],
 "group__rate__control.html#ga4d75c27a723a602ab5b4c497cea07993":[12,2,0,2,36],
-"group__rate__control.html#ga50283a647b83308a9a7c02b74a980ac1":[12,2,0,2,12],
+"group__rate__control.html#ga50283a647b83308a9a7c02b74a980ac1":[12,2,0,2,10],
 "group__rate__control.html#ga5aa5d85250b9dd9951113b4c7053dd43":[12,2,0,2,35],
 "group__rate__control.html#ga653667e5cc76259acc233c1986546599":[12,2,0,2,33],
-"group__rate__control.html#ga6853e4fcc63f2f54ae429e27286827ae":[12,2,0,2,9],
+"group__rate__control.html#ga6853e4fcc63f2f54ae429e27286827ae":[12,2,0,2,8],
 "group__rate__control.html#ga697e00462bcbc3165ed0f7bd25a88925":[12,2,0,2,0],
-"group__rate__control.html#ga6ae4ccee614dac82eb20d16c30d6cbe9":[12,2,0,2,7],
 "group__rate__control.html#ga7778c29e995a78b2521fe4f0bab0c9c1":[12,2,0,2,26],
-"group__rate__control.html#ga788dbcf3c2f97056f0ca1fd644a4535f":[12,2,0,2,23],
+"group__rate__control.html#ga788dbcf3c2f97056f0ca1fd644a4535f":[12,2,0,2,22],
 "group__rate__control.html#ga81e2619f5917dda2803f37c76080c3e5":[12,2,0,2,3],
-"group__rate__control.html#ga8cc1e01e3fb0a620ea3a7ab53d94eb6e":[12,2,0,2,19],
-"group__rate__control.html#ga9c1efbd9f79914ed44ee7a6a795381d5":[12,2,0,2,37],
+"group__rate__control.html#ga8cc1e01e3fb0a620ea3a7ab53d94eb6e":[12,2,0,2,18],
+"group__rate__control.html#ga9012098755b41f37b57a3cbc81b94391":[12,2,0,2,37],
+"group__rate__control.html#ga9c1efbd9f79914ed44ee7a6a795381d5":[12,2,0,2,38],
 "group__rate__control.html#ga9f777728b7370404522efd914656761a":[12,2,0,2,29],
-"group__rate__control.html#gaa1b79c4de593c5ddccf4f0384d51e901":[12,2,0,2,16],
+"group__rate__control.html#gaa07fd8beaee23818bb11c95e80fcf457":[12,2,0,2,25],
+"group__rate__control.html#gaa1b79c4de593c5ddccf4f0384d51e901":[12,2,0,2,14],
 "group__rate__control.html#gab8e7c90f91decf78f31360e56b7f1be6":[12,2,0,2,34],
-"group__rate__control.html#gabbdc0f8c7b275c67917af9e49a0a18ce":[12,2,0,2,22],
-"group__rate__control.html#gabfb0989110479fa704a1b245a4c4c1cf":[12,2,0,2,21],
-"group__rate__control.html#gac12d62af325ff26685a28bebb0137a65":[12,2,0,2,10],
-"group__rate__control.html#gac1743a047b06169064f57c74288d7537":[12,2,0,2,11],
+"group__rate__control.html#gabbdc0f8c7b275c67917af9e49a0a18ce":[12,2,0,2,21],
+"group__rate__control.html#gabfb0989110479fa704a1b245a4c4c1cf":[12,2,0,2,20],
+"group__rate__control.html#gac1743a047b06169064f57c74288d7537":[12,2,0,2,9],
 "group__rate__control.html#gac4b060420e6d43e341ce36cadbb2ff93":[12,2,0,2,32],
-"group__rate__control.html#gacd9a4ebbc3f3c5203419152558dcb17a":[12,2,0,2,38],
+"group__rate__control.html#gacd9a4ebbc3f3c5203419152558dcb17a":[12,2,0,2,39],
 "group__rate__control.html#gacff14724140f9a2419bc82ef61ef2845":[12,2,0,2,30],
-"group__rate__control.html#gad9722dabdd6c62b9d2fac0551b83fe89":[12,2,0,2,20],
+"group__rate__control.html#gad9722dabdd6c62b9d2fac0551b83fe89":[12,2,0,2,19],
 "group__rate__control.html#gadfe05128d22bba397120763fe132c867":[12,2,0,2,6],
-"group__rate__control.html#gae256aad9cb7fbcb22b6944d5b3053a1f":[12,2,0,2,18],
-"group__rate__control.html#gae9eddc0e6469d28bd0429c03efe97544":[12,2,0,2,14],
-"group__rate__control.html#gaf3b990f88a7036986750f9ae344129e9":[12,2,0,2,24],
-"group__rate__control.html#gaf73c75a80818ad2b556f6d86a7e71c5f":[12,2,0,2,15],
+"group__rate__control.html#gae256aad9cb7fbcb22b6944d5b3053a1f":[12,2,0,2,17],
+"group__rate__control.html#gae9eddc0e6469d28bd0429c03efe97544":[12,2,0,2,12],
+"group__rate__control.html#gaf3b990f88a7036986750f9ae344129e9":[12,2,0,2,23],
+"group__rate__control.html#gaf73c75a80818ad2b556f6d86a7e71c5f":[12,2,0,2,13],
 "group__speed__features.html":[12,2,0,0],
 "group__speed__features.html#ga375df45f353341a53823feb529182b2a":[12,2,0,0,0],
 "group__speed__features.html#ga643ab0df2f1abcad7bcd6a612fdbc8a2":[12,2,0,0,2],
-"group__speed__features.html#ga95ee4b0969a41da950b5c23909d142c4":[12,2,0,0,1],
-"group__src__frame__proc.html":[12,2,0,1],
-"group__src__frame__proc.html#ga1218fcbf46cf0ed039cb10d75a5b45ce":[12,2,0,1,4],
-"group__src__frame__proc.html#ga289f71152390ed0475b366c1d7bf6c28":[12,2,0,1,7],
-"group__src__frame__proc.html#ga447d55c84cdd94dfe30fcbd02b696040":[12,2,0,1,2],
-"group__src__frame__proc.html#ga963071ba6e516f32f733c4824bcdc1fa":[12,2,0,1,1],
-"group__src__frame__proc.html#ga9c815293efdd010ff3def929b5c59765":[12,2,0,1,8],
-"group__src__frame__proc.html#gaccb1a85ea947b2a299cd5f7365544113":[12,2,0,1,3],
-"group__src__frame__proc.html#gae3eb405b3b76356d589451915ac6f297":[12,2,0,1,0],
-"group__src__frame__proc.html#gaf29f803ab5bf3577af9e4f154c39974f":[12,2,0,1,5],
-"group__src__frame__proc.html#gafe00d57ea227ed2ec339a0063463ad45":[12,2,0,1,6],
-"group__tpl__modelling.html":[12,2,0,3]
+"group__speed__features.html#ga95ee4b0969a41da950b5c23909d142c4":[12,2,0,0,1]
 };
