@@ -1,6 +1,5 @@
 var NAVTREEINDEX5 =
 {
-"structAV1__COMP.html#a61ca5f788df7db66a40f902f8929bf3f":[13,0,37,49],
 "structAV1__COMP.html#a62a2e36e5f53412363680d402a958ece":[13,0,37,38],
 "structAV1__COMP.html#a62bdce36b2cdeb4e2a9a5c03b8820afc":[13,0,37,23],
 "structAV1__COMP.html#a630c1c37c763287c2a68cb64be0bbc65":[13,0,37,46],
@@ -249,5 +248,6 @@ var NAVTREEINDEX5 =
 "structCommonModeInfoParams.html#af433ad72e0ce77b148f933667a815650":[13,0,57,8],
 "structCommonQuantParams.html":[13,0,58],
 "structCommonQuantParams.html#a01d6e6e663e708fd230dfa8a4d771320":[13,0,58,4],
-"structCommonQuantParams.html#a0bec28af02aa55ca9f2d44e212fff445":[13,0,58,12]
+"structCommonQuantParams.html#a0bec28af02aa55ca9f2d44e212fff445":[13,0,58,12],
+"structCommonQuantParams.html#a184dcbe8f484a0d1d224f367224a5379":[13,0,58,17]
 };
