@@ -1,6 +1,5 @@
 var NAVTREEINDEX6 =
 {
-"structCommonQuantParams.html#a184dcbe8f484a0d1d224f367224a5379":[13,0,58,17],
 "structCommonQuantParams.html#a2ad05f39cabcdd12d9bd34136788793a":[13,0,58,9],
 "structCommonQuantParams.html#a357284012595df64bd5d687fa667825e":[13,0,58,7],
 "structCommonQuantParams.html#a4f9755f8ced8ec35d3dc0986c4c3ce3b":[13,0,58,11],
@@ -249,5 +248,6 @@ var NAVTREEINDEX6 =
 "structLV__MAP__COEFF__COST.html#a14f9d4c6db67fc6b8f05bc8dded96a67":[13,0,89,2],
 "structLV__MAP__COEFF__COST.html#a21ff28247f7c01445252cf0d4d157726":[13,0,89,5],
 "structLV__MAP__COEFF__COST.html#a3b1604ef5cdf5ef6d5f80b1a2eff97c9":[13,0,89,0],
-"structLV__MAP__COEFF__COST.html#a524b66066193b2d558d701569a309cd2":[13,0,89,4]
+"structLV__MAP__COEFF__COST.html#a524b66066193b2d558d701569a309cd2":[13,0,89,4],
+"structLV__MAP__COEFF__COST.html#ac13625e52afc8b9f56490d9b4e3763c8":[13,0,89,3]
 };
