@@ -1,6 +1,5 @@
 var NAVTREEINDEX9 =
 {
-"structaom__codec__enc__cfg.html#a8f8851455e06db026022d4b01671b122":[12,0,1,5,28],
 "structaom__codec__enc__cfg.html#a9217f81f33c62161df9d94e42f2b77c6":[12,0,1,5,19],
 "structaom__codec__enc__cfg.html#aa4d9838419e94e634a02d710da06c842":[12,0,1,5,33],
 "structaom__codec__enc__cfg.html#aa5c6cede8c820ef29fc3c106aa1227eb":[12,0,1,5,27],
@@ -249,5 +248,6 @@ var NAVTREEINDEX9 =
 "structcfg__options.html#a90a87fa68eae243789f0a8d16c7bc3a6":[12,0,1,4,23],
 "structcfg__options.html#a976938b694d797a9f1c3b0e09b0226af":[12,0,1,4,12],
 "structcfg__options.html#a9fd3d54f22675f4ac15e940a930b9ffb":[12,0,1,4,20],
-"structcfg__options.html#aa1ccf6bfa7fe9a29ea514b99e7700d68":[12,0,1,4,14]
+"structcfg__options.html#aa1ccf6bfa7fe9a29ea514b99e7700d68":[12,0,1,4,14],
+"structcfg__options.html#aab0e968a76c1dd31fbfdee7b099b7828":[12,0,1,4,28]
 };
