@@ -10,5 +10,6 @@ var structHIGH__LEVEL__SPEED__FEATURES =
     [ "second_alt_ref_filtering", "structHIGH__LEVEL__SPEED__FEATURES.html#a1f5862490fb7b03317b66f8578271a30", null ],
     [ "adjust_num_frames_for_arf_filtering", "structHIGH__LEVEL__SPEED__FEATURES.html#a051a749a4550216529cfaf4503dfc7e2", null ],
     [ "accurate_bit_estimate", "structHIGH__LEVEL__SPEED__FEATURES.html#ad4e0881065dd85ccb05b27099c3d8386", null ],
-    [ "weight_calc_level_in_tf", "structHIGH__LEVEL__SPEED__FEATURES.html#a5f0c2d3bb578b7fa5f0015bfff44829c", null ]
+    [ "weight_calc_level_in_tf", "structHIGH__LEVEL__SPEED__FEATURES.html#a5f0c2d3bb578b7fa5f0015bfff44829c", null ],
+    [ "allow_sub_blk_me_in_tf", "structHIGH__LEVEL__SPEED__FEATURES.html#a15eaf485a865db95b8c48c727f2f7bd7", null ]
 ];
\ No newline at end of file
